@@ -1,4 +1,3 @@
-#!/usr/bin/env perl
 use strict;
 use warnings;
 use File::Spec;
@@ -18,7 +17,10 @@ my %knownBadClasses = map {($_=>1)} qw(
   TVirtualRefProxy
 );
 
-my %classes;
+# hack...
+my %classes = map {($_=>1)} qw(
+  ROOT::Fit::FitResult
+);
 open my $fh, '<', File::Spec->catfile('buildtools', 'caps') or die $!;
 while (<$fh>) {
   m{
