@@ -437,7 +437,7 @@ namespace SOOT {
 
 
   SV*
-  ProcessReturnValue(pTHX_ const BasicType& retType, long addr, double addrD, const char* retTypeStr)
+  ProcessReturnValue(pTHX_ const BasicType& retType, long addr, double addrD, const char* retTypeStr, bool isConstructor)
   {
     char* typeStrWithoutPtr;
     char* ptr;
@@ -457,6 +457,8 @@ namespace SOOT {
         croak("FIXME Array return values to be implemented");
         break;
       case eTOBJECT:
+        if (addr == NULL)
+          return &PL_sv_undef;
         // FIXME this is so hideous it's not even funny
         typeStrWithoutPtr = strdup(retTypeStr);
         ptr = typeStrWithoutPtr;
@@ -470,7 +472,10 @@ namespace SOOT {
         //       char* const* where the *'s aren't all at the end
         if (ptr_level > 0)
           *(ptr - ptr_level) = '\0';
-        retval = EncapsulateObject(aTHX_ (TObject*)addr, typeStrWithoutPtr);
+        retval = SOOT::RegisterObject(aTHX_ (TObject*)addr, typeStrWithoutPtr);
+        // If we're not creating a TObject via a constructor, it's likely not outs to delete
+        if (!isConstructor)
+          SOOT::PreventDestruction(aTHX_ retval); // FIXME optimize
         if (ptr_level > 0)
           *(ptr - ptr_level) = ' ';
         free(typeStrWithoutPtr);
@@ -537,6 +542,10 @@ namespace SOOT {
 
     // Determine return type
     char* retTypeStr = constructor ? (char*)className : (char*)mInfo.Type()->TrueName();
+/*    cout << "MINFO="<<mInfo.Name() << " " << mInfo.Title() << " " << mInfo.NArg() << " " << mInfo.FileName() << endl;
+    cout << "CINFO="<<mInfo.MemberOf()->Name()<< endl;
+    cout << retTypeStr << " " << mInfo.Type()->Name() << endl;
+*/
     // FIXME ... defies description
     BasicType retType = GuessTypeFromProto(constructor ? (string(className)+string("*")).c_str() : retTypeStr);
     
@@ -558,7 +567,7 @@ namespace SOOT {
       free(needsCleanup[i]);
 
     //cout << "RETVAL INFO FOR " <<  methName << ": cproto=" << retTypeStr << " mytype=" << gBasicTypeStrings[retType] << endl;
-    return ProcessReturnValue(aTHX_ retType, addr, addrD, retTypeStr);
+    return ProcessReturnValue(aTHX_ retType, addr, addrD, retTypeStr, constructor);
   }
 
 
